#!/usr/bin/env python
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.

"""
test_invirtualenv
----------------------------------

Tests for `invirtualenv` module.
"""
import copy
import difflib
import getpass
import json
import logging
import os
import shutil
import sys
import tempfile
import unittest
from invirtualenv import config, plugin
from invirtualenv.contextmanager import InTemporaryDirectory


class TestConfig(unittest.TestCase):
    orig_sysargv = None
    maxDiff = None
    default_config_dict = {
        'global': {
            'basepython': '',
            'description': 'No description is available',
            'name': '',
            'install_os_packages': False,
            'install_manifest': [],
            'version': '',
            'virtualenv_deploy_dir': '',
            'virtualenv_dir': '/var/tmp/virtualenv',
            'virtualenv_group': '',
            'virtualenv_user': '',
            'virtualenv_version_package': ''
        },
        'pip': {
            'deps': [],
            'pip_version': '',
        },
        'rpm': {
            'deps': [],
            'fail_missing_yum': True
        },
    }

    def setUp(self):
        self.orig_sysargv = sys.argv
        self.tempdir = tempfile.mkdtemp()
        self.venv_dir = os.path.join(self.tempdir, 'test_config')
        os.makedirs(self.venv_dir)

    def tearDown(self):
        if self.orig_sysargv:
            sys.argv = self.orig_sysargv
            del self.orig_sysargv
        if self.venv_dir:
            if os.path.exists(self.venv_dir):
                shutil.rmtree(self.venv_dir)
            self.venv_dir = None

    def test_config_parse_arguments_defaults(self):
        sys.argv = ['foo', 'foo']
        result = config.parse_arguments()
        self.assertEqual(result.name, 'foo')
        self.assertEqual(result.virtualenvgroup, '')
        self.assertEqual(result.virtualenvuser, getpass.getuser())
        self.assertFalse(result.install_os_packages)

    def test_deploy_virtualenv_parse_arguments(self):
        sys.argv = [
            'deploy_virtualenv.py', 'foo',
            '-r', 'requirements_dev.txt',
            '--requirement', 'requirements.txt'
        ]
        result = config.parse_arguments()
        self.assertEqual(result.name, 'foo')
        self.assertListEqual(
            result.requirement, ['requirements_dev.txt', 'requirements.txt']
        )

    def test_config_get_configuration_dict__default(self):
        with InTemporaryDirectory():
            result = config.get_configuration_dict(
                configuration=[],
                value_types=plugin.config_types()
            )
            self.assertIsInstance(result, dict)
            if 'rpm_package' in result.keys():
                del result['rpm_package']
            if 'docker_container' in result.keys():
                del result['docker_container']

            self.assertIn(
                result['global']['virtualenv_dir'],
                [
                    '/var/tmp/virtualenv',
                    '/tmp/virtualenv'
                ]
            )
            result['global']['virtualenv_dir'] = '/var/tmp/virtualenv'

            self.assertTrue(
                result['locations']['package_scripts'].endswith('package_scripts')
            )
            del result['locations']
            result_pretty = json.dumps(result, indent=4, sort_keys=True)
            expected_pretty = json.dumps(
                self.default_config_dict, indent=4, sort_keys=True)
            diff = difflib.unified_diff(
                result_pretty.split('\n'), expected_pretty.split('\n')
            )
            logging.debug('Result: %s' % result_pretty)
            logging.debug('Expected: %s' % expected_pretty)
            logging.debug('Diff: %s' % '\n'.join(diff))
            self.assertDictEqual(result,self.default_config_dict)

    def test_config_get_configuration_dict__substitution(self):
        config_file = os.path.join(self.venv_dir, 'dict_subst.conf')
        expected = copy.copy(self.default_config_dict)
        expected['global']['version'] = '0.0.10'
        with open(config_file, 'w') as config_handle:
            config_handle.write(
                "[global]\nversion=0.0.{{DICT_SUBST|default('0')}}"
            )
        os.environ['DICT_SUBST'] = '10'
        result = config.get_configuration_dict(
            configuration=[config_file],
            value_types=plugin.config_types()
        )
        if 'rpm_package' in result.keys():
            del result['rpm_package']
        if 'docker_container' in result.keys():
            del result['docker_container']

        self.assertIsInstance(result, dict)
        self.assertIn(
            result['global']['virtualenv_dir'],
            [
                '/var/tmp/virtualenv',
                '/tmp/virtualenv'
            ]
        )
        result['global']['virtualenv_dir'] = '/var/tmp/virtualenv'

        self.assertTrue(
            result['locations']['package_scripts'].endswith('package_scripts')
        )
        del result['locations']
        result_pretty = json.dumps(result, indent=4, sort_keys=True)
        expected_pretty = json.dumps(expected, indent=4, sort_keys=True)
        diff = difflib.unified_diff(
            result_pretty.split('\n'), expected_pretty.split('\n')
        )
        logging.debug('Result: %s' % result_pretty)
        logging.debug('Expected: %s' % expected_pretty)
        logging.debug('Diff: %s' % '\n'.join(diff))
        self.assertDictEqual(result, expected)

    def test_config_str_to_list__empty(self):
        result = config.str_to_list('')
        self.assertIsInstance(result, list)
        self.assertFalse(result)

    def test_config_str_to_list__items(self):
        result = config.str_to_list('\rfoo\n')
        self.assertIsInstance(result, list)
        self.assertEqual(result, ['foo'])

    def test_generate_parsed_config_file(self):
        with tempfile.NamedTemporaryFile('w') as source_handle:
            source_handle.write('foo = {{TEST_GEN_CONF}}\n')
            source_handle.flush()
            os.environ['TEST_GEN_CONF'] = '1'
            outfile = config.generate_parsed_config_file(source_handle.name)
            with open(outfile) as out_handle:
                result = out_handle.read()
                self.assertEqual(result, 'foo = 1')
            os.remove(outfile)
            del os.environ['TEST_GEN_CONF']

    def test_plugin_package_formats(self):
        result = plugin.package_formats()
        self.assertIsInstance(result, list)


if __name__ == '__main__':
    test_suite = unittest.TestLoader().loadTestsFromTestCase(TestConfig)
    unittest.TextTestRunner(verbosity=2).run(test_suite)



#!/usr/bin/env python
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.

"""
test_invirtualenv
----------------------------------

Tests for `invirtualenv` module.
"""
import os
import sys
import unittest
from invirtualenv import package


bin_dir = os.path.dirname(
    os.popen('which deploy_virtualenv.py').read().strip()
)
sys.path.append(os.path.join(os.getcwd(), 'scripts'))
sys.path.append(bin_dir)


class TestPackage(unittest.TestCase):

    def test_package_scripts_directory(self):
        result = package.package_scripts_directory()
        self.assertIsInstance(result, str)

    def test_package_versions(self):
        result = package.package_versions('invirtualenv')
        self.assertIsInstance(result, list)

    def test_strip_from_end(self):
        result = package.strip_from_end("hello.conf", '.conf')
        self.assertEqual(result, 'hello')

    def test_strip_from_end__no_suffix_found(self):
        result = package.strip_from_end("hello.baz", '.conf')
        self.assertEqual(result, 'hello.baz')

    def test_latest_package_version(self):
        result = package.latest_package_version('invirtualenv')
        self.assertIsInstance(result, str)

    def test_install_prereq_packages(self):
        result = package.install_prereq_packages(test=True)


if __name__ == '__main__':
    test_suite = unittest.TestLoader().loadTestsFromTestCase(TestPackage)
    unittest.TextTestRunner(verbosity=2).run(test_suite)



#!/usr/bin/env python
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.
import os
import unittest
from invirtualenv.contextmanager import InTemporaryDirectory
from invirtualenv.plugin_base import InvirtualenvPlugin


deploy_conf = """[global]
name = test
basepython = python

[pip]
deps:
    invirtualenv
"""


class TestPluginBase(unittest.TestCase):
    def test__base__generate_wheels(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as config_handle:
                config_handle.write(deploy_conf)
            plugin = InvirtualenvPlugin()
            plugin.hash = 'sha512'
            hashes = plugin.generate_wheel_packages(wheeldir=os.getcwd())
            packages = [filename.split('=')[0] for filename in hashes.keys()]
            self.assertGreater(len(hashes), 0)
            self.assertIn('invirtualenv', packages)
            self.assertIn('sha512:', list(hashes.values())[0])



import os
import unittest
import invirtualenv.contextmanager


class TestContextmanager(unittest.TestCase):
    def test__revert_file(self):
        with invirtualenv.contextmanager.InTemporaryDirectory():
            with open('testfile', 'w') as fh:
                fh.write('original')
            self.assertEqual('original', open('testfile').read())
            with invirtualenv.contextmanager.revert_file('testfile'):
                with open('testfile', 'w') as fh:
                    fh.write('changed')
                self.assertEqual('changed', open('testfile').read())
            self.assertEqual('original', open('testfile').read())

    def test__InTemporaryDir(self):
        with invirtualenv.contextmanager.InTemporaryDirectory() as tempdir:
            self.assertIsInstance(tempdir, str)
            self.assertTrue(os.path.exists(tempdir))



#!/usr/bin/env python
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.

import os
import sys
import unittest
from invirtualenv.cli import parse_cli_arguments, main
from invirtualenv.contextmanager import InTemporaryDirectory
from invirtualenv.plugin import package_formats


class TestCli(unittest.TestCase):
    orig_argv = None

    def setUp(self):
        self._orig_argv = sys.argv

    def tearDown(self):
        if self.orig_argv:
            sys.argv = self._orig_argv
            sys.argv = None

    def test__parse_cli_arguments__defaults(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as write_handle:
                write_handle.write('[global]\nname=foo\n')
            sys.argv = ['invirtualenv']
            if sys.version_info.major < 3:
                with self.assertRaises(SystemExit):
                    result = parse_cli_arguments()
            else:
                result = parse_cli_arguments()

    def test__main__list_plugins(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as write_handle:
                write_handle.write('[global]\nname=foo\n')
            sys.argv = ['invirtualenv', 'list_plugins']
            rc, output = main(test=True)
            self.assertEqual(rc, 0)
            for plugin in package_formats():
                self.assertIn(plugin, output)

    def test__get_setting_command(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as write_handle:
                write_handle.write('[global]\nname=foo\n')
            sys.argv = ['invirtualenv', 'get_setting', 'global', 'name']
            rc, output = main(test=True)
            self.assertEqual(rc, 0)
            self.assertEqual(output, 'foo')

    def test__get_setting_command_invalid_key(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as write_handle:
                write_handle.write('[global]\nname=foo\n')
            sys.argv = ['invirtualenv', 'get_setting', 'global', 'namez']
            rc, output = main(test=True)
            self.assertEqual(rc, 1)
            self.assertEqual(output, '')

    def test__create_package_config__parsed_deploy_conf__outfile(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as write_handle:
                write_handle.write('[global]\ntest={{TESTVAR}}\n')
            os.environ['TESTVAR'] = 'foo'
            sys.argv = ['invirtualenv', 'create_package_config', 'parsed_deploy_conf', '-o', 'deploy.conf.parsed']
            rc, output = main(test=True)
            self.assertTrue(os.path.exists('deploy.conf.parsed'))
            self.assertEqual(rc, 0)
            self.assertIn('deploy.conf.parsed', output)

    def test__create_package_config__parsed_deploy_conf__nooutfile(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as write_handle:
                write_handle.write('[global]\ntest={{TESTVAR}}\n')
            os.environ['TESTVAR'] = 'foo'
            sys.argv = ['invirtualenv', 'create_package_config', 'parsed_deploy_conf']
            rc, output = main(test=True)
            self.assertTrue(os.path.exists('deploy.conf.parsed'))
            self.assertEqual(rc, 0)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.

"""
test_invirtualenv
----------------------------------

Tests for `invirtualenv` module.
"""
try:
    from StringIO import StringIO
except ImportError:
    from io import StringIO
import os
import sys
import unittest
from invirtualenv import utility


class TestUtility(unittest.TestCase):
    stdout_orig = sys.stdout

    def setUp(self):
        sys.stdout = StringIO()

    def tearDown(self):
        sys.stdout = self.stdout_orig

    def test_update_recursive(self):
        dict1 = {
            'a': {
                'b': {
                    'items': [1, 2]
                }
            },
            'c': 'd'
        }
        dict2 = {
            'a': {
                'b': {
                    'otheritems': [3, 4]
                },
            },
            'c': 'e'
        }
        expected_result = {
            'a': {
                'b': {
                    'items': [1, 2],
                    'otheritems': [3, 4]
                }
            },
            'c': 'e'
        }
        result = utility.update_recursive(dict1, dict2)
        self.assertDictEqual(result, expected_result)

    def test_utility_header(self):
        utility.display_header('Test message')
        output = sys.stdout.getvalue()
        sys.stdout = self.stdout_orig
        self.assertIn('===', output)
        self.assertIn(os.linesep + 'Test message', output)
        self.assertEqual(
            len(output.split(os.linesep)),
            4,
            'Output of %r is not a single line' % output
        )

    def test_utility_header__collapse(self):
        utility.display_header('Test message', collapse=True)
        output = sys.stdout.getvalue()
        self.assertIn('===', output)
        self.assertIn('Test message', output)
        self.assertEqual(
            len(output.split(os.linesep)),
            2,
            'Output of %r is not a single line' % output
        )

    def test__str_format_env__substitue(self):
        env_value = 'foo'
        os.environ['str_format_env'] = env_value
        result = utility.str_format_env('{{str_format_env}}')
        self.assertEqual(result, env_value)
        del os.environ['str_format_env']

    def test__str_to_env_to_list(self):
        env_value = 'foo'
        os.environ['str_format_env'] = env_value
        result = utility.str_format_env('bar')
        self.assertEqual(result, 'bar')
        del os.environ['str_format_env']

    def test__csv_list(self):
        result = utility.csv_list('1,2')
        self.assertEqual(result, ['1', '2'])


if __name__ == '__main__':
    test_suite = unittest.TestLoader().loadTestsFromTestCase(TestUtility)
    unittest.TextTestRunner(verbosity=2).run(test_suite)



#!/usr/bin/env python
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.
import os
import unittest
from invirtualenv.contextmanager import InTemporaryDirectory
from invirtualenv_plugins.parsedconfig import InvirtualenvParsedConfig


deploy_conf = """[global]
name = test
basepython = python

[pip]
deps:
    confset
"""


class TestPluginBase(unittest.TestCase):
    def test__config_file__argument(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as config_handle:
                config_handle.write(deploy_conf)
            plugin = InvirtualenvParsedConfig(config_file='deploy.conf')
            self.assertEqual(plugin.config_file, 'deploy.conf')
            self.assertEqual(plugin.config['global']['name'], 'test')

    def test__config_file__create(self):
        with InTemporaryDirectory():
            with open('deploy.conf', 'w') as config_handle:
                config_handle.write(deploy_conf)
            plugin = InvirtualenvParsedConfig(config_file='deploy.conf')
            plugin.create_package('parsed_deploy_conf')



#!/usr/bin/env python
"""
test_invirtualenv
----------------------------------

Tests for `invirtualenv` module.
"""
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.

import getpass
import json
import os
import pwd
import shutil
import subprocess
import sys
import tempfile
import unittest
from invirtualenv import deploy
from invirtualenv.contextmanager import TemporaryDirectory


class TestDeploy(unittest.TestCase):
    orig_sysargv = None
    maxDiff = None
    verbose = True

    def setUp(self):
        self.orig_sysargv = sys.argv
        self.tempdir = tempfile.mkdtemp()
        self.venv_dir = os.path.join(self.tempdir, 'test_config')
        os.makedirs(self.venv_dir)

    def tearDown(self):
        if self.orig_sysargv:
            sys.argv = self.orig_sysargv
            del self.orig_sysargv
        if self.venv_dir:
            if os.path.exists(self.venv_dir):
                shutil.rmtree(self.venv_dir)
            self.venv_dir = None

    @unittest.skipUnless(os.getuid() == 0, "This test requires root")
    def test__fix_file_ownership__as_root(self):
        venv = os.path.join(self.venv_dir, 'testvenv')
        nobody = pwd.getpwnam('nobody')
        current_user = pwd.getpwnam(getpass.getuser())
        os.makedirs(venv)
        self.assertEqual(os.stat(venv).st_uid, current_user.pw_uid)
        self.assertEqual(os.stat(venv).st_gid, current_user.pw_gid)
        deploy.fix_file_ownership(venv, nobody.pw_uid, nobody.pw_gid)
        self.assertEqual(os.stat(venv).st_uid, nobody.pw_uid)
        self.assertEqual(os.stat(venv).st_gid, nobody.pw_gid)

    def test__fix_file_ownership__as_user(self):
        venv = os.path.join(self.venv_dir, 'testvenv')
        current_user = pwd.getpwnam(getpass.getuser())
        nobody = current_user
        os.makedirs(venv)
        self.assertEqual(os.stat(venv).st_uid, current_user.pw_uid)
        self.assertEqual(os.stat(venv).st_gid, current_user.pw_gid)
        deploy.fix_file_ownership(venv, nobody.pw_uid, nobody.pw_gid)
        self.assertEqual(os.stat(venv).st_uid, nobody.pw_uid)
        self.assertEqual(os.stat(venv).st_gid, nobody.pw_gid)

    def test__build_deploy_virtualenv(self):
        sys.argv = ['foo']
        venv_name = 'deploy_default'
        venv_path = os.path.join(self.venv_dir, venv_name)
        config_file = os.path.join(self.venv_dir, 'deploy_default.conf')
        with open(config_file, 'w') as config_handle:
            config_handle.write(
                "[global]\nname=%s\nvirtualenv_dir=%s\n"
                "[pip]\ndeps:\n    pip\n" % (
                    venv_name,
                    self.venv_dir
                )
            )
        deploy.build_deploy_virtualenv(
            configuration=[config_file],
            verbose=self.verbose
        )
        self.assertTrue(os.path.isdir(venv_path))

    def test__build_deploy_virtualenv__no_pips(self):
        sys.argv = ['foo']
        venv_name = 'deploy_default'
        venv_path = os.path.join(self.venv_dir, venv_name)
        config_file = os.path.join(self.venv_dir, 'deploy_default.conf')
        with open(config_file, 'w') as config_handle:
            config_handle.write(
                "[global]\nname=%s\nvirtualenv_dir=%s\n" % (
                    venv_name,
                    self.venv_dir
                )
            )
        deploy.build_deploy_virtualenv(
            configuration=[config_file],
            verbose=self.verbose
        )
        self.assertTrue(os.path.isdir(venv_path))
        confdir = os.path.join(venv_path, 'conf')
        self.assertTrue(os.path.isdir(confdir))
        self.assertTrue(
            os.path.exists(
                os.path.join(confdir, 'binfiles_predeploy.json')
            )
        )

    def test__build_deploy_virtualenv__pips(self):
        sys.argv = ['foo']
        venv_name = 'deploy_default'
        venv_path = os.path.join(self.venv_dir, venv_name)
        config_file = os.path.join(self.venv_dir, 'deploy_default.conf')
        with open(config_file, 'w') as config_handle:
            config_handle.write(
                "[global]\nname=%s\nvirtualenv_dir=%s\n"
                "[pip]\ndeps=serviceping<18.0.0\n" % (
                    venv_name,
                    self.venv_dir
                )
            )
        deploy.build_deploy_virtualenv(configuration=[config_file], verbose=self.verbose)
        self.assertTrue(os.path.isdir(venv_path))
        confdir = os.path.join(venv_path, 'conf')
        predeploy_file = os.path.join(confdir, 'binfiles_predeploy.json')
        postdeploy_file = os.path.join(confdir, 'binfiles_postdeploy.json')
        self.assertTrue(os.path.isdir(confdir))
        print(os.listdir(confdir))
        self.assertTrue(os.path.exists(predeploy_file))
        self.assertTrue(os.path.exists(postdeploy_file))
        with open(predeploy_file, 'r') as predeploy_handle:
            predeploy = json.load(predeploy_handle)
            print('predeploy', predeploy)
            self.assertIsInstance(predeploy, dict)
        with open(postdeploy_file, 'r') as postdeploy_handle:
            postdeploy = json.load(postdeploy_handle)
            print('postdeploy', postdeploy)
            self.assertIsInstance(postdeploy, dict)
        self.assertEqual(list(deploy.deployed_bin_files(venv_path).keys()), ['serviceping'])

    @unittest.skipUnless(os.getuid() == 0, "This test requires root")
    def test__build_deploy_virtualenv__pips__linkbins(self):
        sys.argv = ['foo']
        venv_name = 'deploy_default'
        venv_path = os.path.join(self.venv_dir, venv_name)
        config_file = os.path.join(self.venv_dir, 'deploy_default.conf')
        with open(config_file, 'w') as config_handle:
            config_handle.write(
                "[global]\nname=%s\nvirtualenv_dir=%s\n"
                "[pip]\ndeps=serviceping<18.0.0\n" % (
                    venv_name,
                    self.venv_dir
                )
            )
        deploy.build_deploy_virtualenv(
            configuration=[config_file],
            verbose=self.verbose
        )
        with TemporaryDirectory() as bindir:
            deploy.link_deployed_bin_files(venv_path, bindir)
            self.assertIn('serviceping', os.listdir(bindir))
            deploy.unlink_deployed_bin_files(venv_path)
            self.assertEqual([], os.listdir(bindir))

    def test__build_deploy_virtualenv__package_tools__up_to_date(self):
        sys.argv = ['foo']
        venv_name = 'deploy_default'
        venv_path = os.path.join(self.venv_dir, venv_name)
        venv_bin_dir = os.path.join(venv_path, 'bin')
        venv_pip = os.path.join(venv_bin_dir, 'pip')
        config_file = os.path.join(self.venv_dir, 'deploy_default.conf')
        major_versions = {
            'pip': 9,
            'setuptools': 36
        }
        with open(config_file, 'w') as config_handle:
            config_handle.write(
                "[global]\nname=%s\nvirtualenv_dir=%s\n"
                "[pip]\ndeps=serviceping<18.0.0\n" % (
                    venv_name,
                    self.venv_dir
                )
            )
        deploy.build_deploy_virtualenv(configuration=[config_file], verbose=self.verbose)
        output = subprocess.check_output([venv_pip, 'list', '--format=columns'])
        for line in output.decode().split(os.linesep):
            try:
                package, version = line.split()
            except ValueError:
                continue
            package = package.strip()
            if package in major_versions.keys():
                version = version.strip('(').strip(')')
                major = int(version.split('.')[0])
                self.assertGreaterEqual(major, major_versions[package])


if __name__ == '__main__':
    test_suite = unittest.TestLoader().loadTestsFromTestCase(TestDeploy)
    unittest.TextTestRunner(verbosity=2).run(test_suite)



#!/usr/bin/env python
# Copyright (c) 2016, Yahoo Inc.
# Copyrights licensed under the BSD License
# See the accompanying LICENSE.txt file for terms.

"""
test_invirtualenv
----------------------------------

Tests for `invirtualenv` module.
"""
import unittest


class TestImport(unittest.TestCase):

    def test_import_invirtualenv(self):
        import invirtualenv

    def test_import_invirtualenv_config(self):
        import invirtualenv.config

    def test_import_invirtualenv_deploy(self):
        import invirtualenv.deploy

    def test_import_invirtualenv_exceptions(self):
        import invirtualenv.exceptions

    def test_import_invirtualenv_package(self):
        import invirtualenv.package

    def test_import_invirtualenv_utility(self):
        import invirtualenv.utility

    def test_import_invirtualenv_virtualenv(self):
        import invirtualenv.virtualenv

    def test_import_invirtualenv_plugin(self):
        import invirtualenv.plugin


if __name__ == '__main__':
    test_suite = unittest.TestLoader().loadTestsFromTestCase(TestImport)
    unittest.TextTestRunner(verbosity=2).run(test_suite)
